@@ -152,6 +152,9 @@ scale_transform <- function(x, scale, map = FALSE, arg = caller_arg(x)) {
       "The key {.field {arg}} must be {.emph continuous}, not discrete."
     )
   }
+  if (inherits(x, "AsIs")) {
+    return(x)
+  }
   transform <- scale$get_transformation()
   if (is.null(transform)) {
     if (map) {
@@ -302,3 +305,10 @@ extra_args <- function(..., .valid_args = .label_params, call = caller_env()) {
   names(args) <- paste0(".", names(args))
   args
 }
+
+descale <- function(x, to = c(0, 1), from = c(0, 1)) {
+  if (!is.numeric(x) | !inherits(x, "AsIs")) {
+    return(x)
+  }
+  rescale(as.numeric(x), to = to, from = from)
+}
